@@ -16,6 +16,7 @@
 #include "cssmanager.h"
 
 #include <gtkmm.h>
+#include <sys/time.h>
 
 namespace ARTICLE
 {
@@ -134,11 +135,14 @@ namespace ARTICLE
         // 状態
         int m_x_pointer, m_y_pointer;  // 現在のマウスポインタの位置
         bool m_key_press; // キーを押している
+        bool m_key_locked; // 同じキーを押したままにしている
+        guint m_keyval;
         bool m_drugging;  // ドラッグ中
         bool m_r_drugging; // 右ドラッグ中
         std::string m_link_current; // 現在マウスポインタの下にあるリンクの文字列
         LAYOUT* m_layout_current; // 現在マウスポインタの下にあるlayoutノード(下が空白ならNULL)
         Gdk::CursorType m_cursor_type; // カーソルの形状
+        struct timeval m_draw_time;  // 最後に描画した時刻
 
         // 入力コントローラ
         CONTROL::Control m_control;
@@ -264,7 +268,7 @@ namespace ARTICLE
         const bool is_drawarea_realized(){ return m_window; }
 
         // バックスクリーン描画
-        bool draw_backscreen( const bool redraw_all = false );
+        const bool draw_backscreen( const bool redraw_all = false );
 
         // 文字色のID( colorid.h にある ID を指定)
         const int get_colorid_text() const{ return m_colorid_text; }
