@@ -45,6 +45,7 @@ std::string get_default_font()
     IS_DEFAULT_FONT( "IPAMonaPGothic" );
     IS_DEFAULT_FONT( "Mona-VLGothic" );
     IS_DEFAULT_FONT( "Mona" );
+    IS_DEFAULT_FONT( "Konatu" );
     IS_DEFAULT_FONT( "VL Pゴシック" );
     IS_DEFAULT_FONT( "VL PGothic" );
     IS_DEFAULT_FONT( "さざなみゴシック" );
@@ -153,7 +154,8 @@ const bool ConfigItems::load( const bool restore )
     x_2ch_ua = cf.get_option_str( "x_2ch_ua", CONF_X_2CH_UA );
 
     // ローダのバッファサイズ
-    loader_bufsize = cf.get_option_int( "loader_bufsize", CONF_LOADER_BUFSIZE, 8, 4096 );
+    loader_bufsize = cf.get_option_int( "loader_bufsize", CONF_LOADER_BUFSIZE, 1, 4096 ); // 一般
+    loader_bufsize_board = cf.get_option_int( "loader_bufsize_board", CONF_LOADER_BUFSIZE_BOARD, 1, 4096 ); // スレ一覧用
 
     // ローダのタイムアウト値
     loader_timeout = cf.get_option_int( "loader_timeout", CONF_LOADER_TIMEOUT, 1, 120 );
@@ -221,6 +223,9 @@ const bool ConfigItems::load( const bool restore )
     // 画像の最大サイズ(Mピクセル)
     max_img_pixel = cf.get_option_int( "max_img_pixel", CONF_MAX_IMG_PIXEL, 1, 1024 );
 
+    // 画像のメモリキャッシュ枚数
+    imgcache_size = cf.get_option_int( "imgcache_size", CONF_IMGCACHE_SIZE, 0, 20 );
+
     // JD ホームページのアドレス
     url_jdhp = cf.get_option_str( "url_jdhp", CONF_URL_JDHP );
 
@@ -257,6 +262,9 @@ const bool ConfigItems::load( const bool restore )
     // ツリービューでgtkrcの設定を使用するか
     use_tree_gtkrc = cf.get_option_bool( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
 
+    // スレビューの選択色でgtkrcの設定を使用するか
+    use_select_gtkrc = cf.get_option_bool( "use_select_gtkrc", CONF_USE_SELECT_GTKRC );
+
     // ツリービューの行間スペース
     tree_ypad = cf.get_option_int( "tree_ypad", CONF_TREE_YPAD, 0, 64 );
 
@@ -275,6 +283,12 @@ const bool ConfigItems::load( const bool restore )
     // スレ一覧でdeleteを押したときに確認ダイアログを表示する
     show_deldiag = cf.get_option_bool( "show_deldiag", CONF_SHOW_DELDIAG );
 
+    // スレ一覧をロードする前にキャッシュにある一覧を表示
+    show_cached_board = cf.get_option_bool( "show_cached_board", CONF_SHOW_CACHED_BOARD );
+
+    // スレ一覧でお知らせスレ(924)のアイコンを表示する
+    show_924 = cf.get_option_bool( "show_924", CONF_SHOW_924 );
+ 
     // ツリービューのスクロール量(行数)
     tree_scroll_size = cf.get_option_int( "tree_scroll_size", CONF_TREE_SCROLL_SIZE, 1, 64 );
 
@@ -326,6 +340,9 @@ const bool ConfigItems::load( const bool restore )
     // 非アクティブ時に書き込みビューを折りたたむ
     fold_message = cf.get_option_bool( "fold_message", CONF_FOLD_MESSAGE );
 
+    // 書き込み欄の日本語のON/OFF状態を保存
+    keep_im_status = cf.get_option_bool( "keep_im_status", CONF_KEEP_IM_STATUS );
+
     // ポップアップとカーソルの間のマージン
     margin_popup = cf.get_option_int( "margin_popup", CONF_MARGIN_POPUP, 1, 1024 );
 
@@ -335,8 +352,11 @@ const bool ConfigItems::load( const bool restore )
     // マウスジェスチャの判定開始半径
     mouse_radius = cf.get_option_int( "mouse_radius", CONF_MOUSE_RADIUS, 4, 1024 );
 
-    // 履歴の保持数
-    history_size = cf.get_option_int( "history_size", CONF_HISTORY, 0, 65535 );
+    // 履歴メニューの表示数
+    history_size = cf.get_option_int( "history_size", CONF_HISTORY_SIZE, 0, 256 );
+
+    // 履歴ビューの表示数
+    historyview_size = cf.get_option_int( "historyview_size", CONF_HISTORYVIEW_SIZE, 0, 1024 );
 
     // AA履歴の保持数
     aahistory_size = cf.get_option_int( "aahistory_size", CONF_AAHISTORY, 0, 65535 );
@@ -453,12 +473,18 @@ const bool ConfigItems::load( const bool restore )
     // お気に入りの更新チェック時に板の更新もチェックする
     check_update_board  = cf.get_option_bool( "check_update_board", CONF_CHECK_UPDATE_BOARD );
 
+    // 起動時にお気に入りを自動でチェックする
+    check_update_boot = cf.get_option_bool( "check_update_boot", CONF_CHECK_UPDATE_BOOT );
+
     // Ctrl+qでウィンドウを閉じない
     disable_close = cf.get_option_bool( "disable_close", CONF_DISABLE_CLOSE );
 
     // まちBBSの取得に offlaw.cgi を使用する
     use_machi_offlaw = cf.get_option_bool( "use_machi_offlaw", CONF_USE_MACHI_OFFLAW );
 
+    // 書き込み履歴のあるスレを削除する時にダイアログを表示
+    show_del_written_thread_diag = cf.get_option_bool( "show_del_written_thread_diag", CONF_SHOW_DEL_WRITTEN_THREAD_DIAG );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     migemodict_path = cf.get_option_str( "migemodict_path", CONF_MIGEMO_PATH );
@@ -490,7 +516,7 @@ const bool ConfigItems::load( const bool restore )
         }
     }
     // 正常ならバックアップ
-    else
+    else if( CACHE::file_exists( CACHE::path_root() ) == CACHE::EXIST_DIR )
     {
         save_impl( CACHE::path_conf_bkup() );
     }
@@ -572,6 +598,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "x_2ch_ua", x_2ch_ua );
 
     cf.update( "loader_bufsize", loader_bufsize );
+    cf.update( "loader_bufsize_board", loader_bufsize_board );
+
     cf.update( "loader_timeout", loader_timeout );
     cf.update( "loader_timeout_post", loader_timeout_post );
     cf.update( "loader_timeout_img", loader_timeout_img );
@@ -602,6 +630,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "del_imgabone_day", del_imgabone_day );
     cf.update( "max_img_size", max_img_size );
     cf.update( "max_img_pixel", max_img_pixel );
+    cf.update( "imgcache_size", imgcache_size );
 
     cf.update( "cl_char", str_color[ COLOR_CHAR ] );
     cf.update( "cl_char_name", str_color[ COLOR_CHAR_NAME ] );
@@ -638,6 +667,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_back_board_even", str_color[ COLOR_BACK_BOARD_EVEN ] );
 
     cf.update( "use_tree_gtkrc", use_tree_gtkrc );
+    cf.update( "use_select_gtkrc", use_select_gtkrc );
 
     cf.update( "tree_ypad", tree_ypad );
 
@@ -647,6 +677,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "newthread_hour", newthread_hour );
     cf.update( "inc_search_board", inc_search_board );
     cf.update( "show_deldiag", show_deldiag );
+    cf.update( "show_cached_board", show_cached_board );
+    cf.update( "show_924", show_924 );
 
     cf.update( "tree_scroll_size", tree_scroll_size );
     cf.update( "scroll_size", scroll_size );
@@ -667,10 +699,12 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "save_posthist", save_posthist );
     cf.update( "hide_writing_dialog", hide_writing_dialog );
     cf.update( "fold_message", fold_message );
+    cf.update( "keep_im_status", keep_im_status );
     cf.update( "margin_popup", margin_popup );
     cf.update( "margin_imgpopup", margin_imgpopup );
     cf.update( "mouse_radius", mouse_radius );
     cf.update( "history_size", history_size );
+    cf.update( "historyview_size", historyview_size );
     cf.update( "aahistory_size", aahistory_size );
     cf.update( "instruct_popup", instruct_popup );
     cf.update( "instruct_tglart", instruct_tglart );
@@ -732,8 +766,10 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "show_diag_replace_favorite", show_diag_replace_favorite );
     cf.update( "bookmark_drop", bookmark_drop );
     cf.update( "check_update_board", check_update_board );
+    cf.update( "check_update_boot", check_update_boot );
     cf.update( "disable_close", disable_close );
     cf.update( "use_machi_offlaw", use_machi_offlaw );
+    cf.update( "show_del_written_thread_diag", show_del_written_thread_diag );
 
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
