@@ -14,9 +14,9 @@
 //#define JDVERSION_SVN
 
 #define MAJORVERSION 2
-#define MINORVERSION 2
-#define MICROVERSION 0
-#define JDDATE    "090212"
+#define MINORVERSION 5
+#define MICROVERSION 5
+#define JDDATE    "091228"
 #define JDTAG     ""
 
 //---------------------------------
@@ -56,3 +56,36 @@
     "Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA)。\n"
 
 #endif
+
+//---------------------------------
+// for windres.rc
+#ifndef DEBUG
+#define JDVER_DEBUG             0
+#else
+#define JDVER_DEBUG             VS_FF_DEBUG
+#endif
+
+#define JDVER_FILEVERSION       MAJORVERSION,MINORVERSION,MICROVERSION,0
+#define JDVER_PRODUCTVERSION    JDVER_FILEVERSION
+
+// Two macros expansion is gcc preprocessor technic
+#define JDRC_VERSION_EXP(a,b,c,d,e) JDRC_VERSION_FMT(a,b,c,d,e)
+#ifdef JDVERSION_SVN
+#define JDRC_VERSION_FMT(a,b,c,d,e) #a "." #b "." #c "-svnversion"
+#else
+#define JDRC_VERSION_FMT(a,b,c,d,e) #a "." #b "." #c "-" d e
+#endif
+#define JDRC_VERSION_STR JDRC_VERSION_EXP( \
+            MAJORVERSION, MINORVERSION, MICROVERSION, JDTAG, JDDATE)
+
+#define JDRC_FILEVERSION        JDRC_VERSION_STR
+#define JDRC_PRODUCTVERSION     JDRC_FILEVERSION
+
+#define JDRC_PRODUCTNAME        "JD for Linux"
+#define JDRC_INTERNALNAME       "JD"
+#define JDRC_ORIGINALFILENAME   "jd.exe"
+#define JDRC_COMPANYNAME        "JD project"
+#define JDRC_FILEDESCRIPTION    JDRC_PRODUCTNAME
+#define JDRC_COMMENTS           JDRC_PRODUCTNAME
+#define JDRC_LEGALCOPYRIGHT     JDCOPYRIGHT
+
