@@ -33,6 +33,7 @@ View::View( const std::string& url, const std::string& arg1 ,const std::string&
       m_keyjump_num( 0 ),
       m_lockable( true ),
       m_locked( false ),
+      m_writeable( true ),
       m_id_toolbar( 0 )
 {}
 
@@ -175,13 +176,18 @@ const bool View::release_keyjump_key( int key )
 
 
 // view 上にマウスポインタがあれば true
-bool View::is_mouse_on_view()
+const bool View::is_mouse_on_view()
 {
     bool ret = false;
 
     int x,y;
     get_pointer( x, y );
-    if( x <= get_width() && x >= 0 && y <= get_height() && y >= 0 ) ret = true;
+    if( x < get_width() && x >= 0 && y < get_height() && y >= 0 ) ret = true;
+
+#ifdef _DEBUG
+    std::cout << "View::is_mouse_on_view ret = " << ret
+              << " x= " << x << " y= " << y << " w= " << get_width() << " h= " << get_height() << std::endl;
+#endif
 
     return ret;
 }
@@ -197,12 +203,19 @@ void View::show_popupmenu( const std::string& url, bool use_slot )
     Gtk::Menu* popupmenu = get_popupmenu( url );
     if( popupmenu ){
 
-        popupmenu->signal_hide().connect( sigc::mem_fun( *this, &View::slot_hide_popupmenu ) ); 
+#ifdef _DEBUG
+        std::cout << "View::show_popupmenu\n";
+#endif
+
+        if( m_url_popup.find( url ) == m_url_popup.end() ){
+
+            m_url_popup.insert( url );
+            popupmenu->signal_map().connect( sigc::mem_fun( *this, &View::slot_map_popupmenu ) ); 
+            popupmenu->signal_hide().connect( sigc::mem_fun( *this, &View::slot_hide_popupmenu ) );
+        }
 
         if( use_slot ) popupmenu->popup( sigc::mem_fun( *this, &View::slot_popup_menu_position ), 0, gtk_get_current_event_time() );
         else popupmenu->popup( 0, gtk_get_current_event_time() );
-
-        SESSION::set_popupmenu_shown( true );
     }
 }
 
@@ -220,11 +233,28 @@ void View::slot_popup_menu_position( int& x, int& y, bool& push_in)
 }
 
 
+//
+// ポップアップメニューがmapしたときに呼ばれるslot
+//
+void View::slot_map_popupmenu()
+{
+#ifdef _DEBUG
+    std::cout << "View::slot_map_popupmenu\n";
+#endif
+
+    SESSION::set_popupmenu_shown( true );
+}
+
+
 //
 // ポップアップメニューがhideしたときに呼ばれるslot
 //
 void View::slot_hide_popupmenu()
 {
+#ifdef _DEBUG
+    std::cout << "View::slot_hide_popupmenu\n";
+#endif
+
     SESSION::set_popupmenu_shown( false );
 
     // もしviewがポップアップウィンドウ上にあって、かつ
